..
    Copyright (C) 2021 Graz University of Technology.

    invenio-imoox is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.Installation

Installation
============

invenio-imoox is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-imoox
